@@ -25,13 +25,10 @@
 //! feature is enabled.
 
 mod cookie;
-mod jar;
 pub(crate) mod interceptor;
+mod jar;
 
 #[cfg(feature = "psl")]
 mod psl;
 
-pub use self::{
-    cookie::Cookie,
-    jar::CookieJar,
-};
+pub use self::{cookie::Cookie, jar::CookieJar};
